Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(35)

Unified Diff: third_party/logilab/astng/nodes.py

Issue 719313003: Revert "pylint: upgrade to 1.3.1" (Closed) Base URL: https://chromium.googlesource.com/chromium/tools/depot_tools.git@master
Patch Set: Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/logilab/astng/node_classes.py ('k') | third_party/logilab/astng/protocols.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/logilab/astng/nodes.py
diff --git a/third_party/logilab/astroid/nodes.py b/third_party/logilab/astng/nodes.py
similarity index 75%
rename from third_party/logilab/astroid/nodes.py
rename to third_party/logilab/astng/nodes.py
index 263ab476c6a58884f691f9451157647396bf100f..56b9980f6b41f7d62313122a6244267c7160e6d4 100644
--- a/third_party/logilab/astroid/nodes.py
+++ b/third_party/logilab/astng/nodes.py
@@ -1,20 +1,22 @@
-# copyright 2003-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+# copyright 2003-2010 Sylvain Thenault, all rights reserved.
+# contact mailto:thenault@gmail.com
#
# This file is part of astroid.
#
# astroid is free software: you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by the
# Free Software Foundation, either version 2.1 of the License, or (at your
# option) any later version.
#
# astroid is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
# for more details.
#
# You should have received a copy of the GNU Lesser General Public License along
-# with astroid. If not, see <http://www.gnu.org/licenses/>.
+# with logilab-astng. If not, see <http://www.gnu.org/licenses/>.
"""
on all nodes :
.is_statement, returning true if the node should be considered as a
@@ -26,7 +28,7 @@ on all nodes :
.frame(), returning the first node defining a new local scope (i.e.
Module, Function or Class)
.set_local(name, node), define an identifier <name> on the first parent frame,
- with the node defining it. This is used by the astroid builder and should not
+ with the node defining it. This is used by the astng builder and should not
be used from out there.
on From and Import :
@@ -37,15 +39,15 @@ on From and Import :
__docformat__ = "restructuredtext en"
-from astroid.node_classes import Arguments, AssAttr, Assert, Assign, \
+from logilab.astng.node_classes import Arguments, AssAttr, Assert, Assign, \
AssName, AugAssign, Backquote, BinOp, BoolOp, Break, CallFunc, Compare, \
Comprehension, Const, Continue, Decorators, DelAttr, DelName, Delete, \
Dict, Discard, Ellipsis, EmptyNode, ExceptHandler, Exec, ExtSlice, For, \
From, Getattr, Global, If, IfExp, Import, Index, Keyword, \
List, Name, Nonlocal, Pass, Print, Raise, Return, Set, Slice, Starred, Subscript, \
- TryExcept, TryFinally, Tuple, UnaryOp, While, With, Yield, YieldFrom, \
+ TryExcept, TryFinally, Tuple, UnaryOp, While, With, Yield, \
const_factory
-from astroid.scoped_nodes import Module, GenExpr, Lambda, DictComp, \
+from logilab.astng.scoped_nodes import Module, GenExpr, Lambda, DictComp, \
ListComp, SetComp, Function, Class
ALL_NODE_CLASSES = (
@@ -68,6 +70,6 @@ ALL_NODE_CLASSES = (
TryExcept, TryFinally, Tuple,
UnaryOp,
While, With,
- Yield, YieldFrom
+ Yield,
)
« no previous file with comments | « third_party/logilab/astng/node_classes.py ('k') | third_party/logilab/astng/protocols.py » ('j') | no next file with comments »
@@ -1,20 +1,22 @@
#
-# This file is part of astroid.
+# This file is part of logilab-astng.
#
@@ -1,20 +1,22 @@
#
-# astroid is free software: you can redistribute it and/or modify it
+# logilab-astng is free software: you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by the
# Free Software Foundation, either version 2.1 of the License, or (at your
@@ -1,20 +1,22 @@
# option) any later version.
#
-# astroid is distributed in the hope that it will be useful, but
+# logilab-astng is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License

Powered by Google App Engine
This is Rietveld 408576698